public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Liming Gao" <liming.gao@intel.com>
To: Philippe Mathieu-Daude <philmd@redhat.com>,
	"devel@edk2.groups.io" <devel@edk2.groups.io>
Cc: Antoine Coeur <coeur@gmx.fr>,
	"Kinney, Michael D" <michael.d.kinney@intel.com>
Subject: Re: [PATCH v2 26/78] MdePkg/Library/Smm: Fix various typos
Date: Mon, 6 Jan 2020 03:35:53 +0000	[thread overview]
Message-ID: <4A89E2EF3DFEDB4C8BFDE51014F606A14E58A495@SHSMSX104.ccr.corp.intel.com> (raw)
In-Reply-To: <20200103090812.10592-27-philmd@redhat.com>

Reviewed-by: Liming Gao <liming.gao@intel.com>

-----Original Message-----
From: Philippe Mathieu-Daude <philmd@redhat.com> 
Sent: 2020年1月3日 17:07
To: devel@edk2.groups.io
Cc: Antoine Coeur <coeur@gmx.fr>; Kinney, Michael D <michael.d.kinney@intel.com>; Gao, Liming <liming.gao@intel.com>; Philippe Mathieu-Daude <philmd@redhat.com>
Subject: [PATCH v2 26/78] MdePkg/Library/Smm: Fix various typos

From: Antoine Coeur <coeur@gmx.fr>

Fix various typos in comments and documentation.

Cc: Michael D Kinney <michael.d.kinney@intel.com>
Cc: Liming Gao <liming.gao@intel.com>
Signed-off-by: Antoine Coeur <coeur@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <philmd@redhat.com>
Reviewed-by: Michael D Kinney <michael.d.kinney@intel.com>
Signed-off-by: Philippe Mathieu-Daude <philmd@redhat.com>
---
 MdePkg/Include/Library/SmmLib.h               |  4 +-
 MdePkg/Include/Library/SmmMemLib.h            |  4 +-
 MdePkg/Include/Library/SmmPeriodicSmiLib.h    |  6 +--
 MdePkg/Library/SmmMemLib/SmmMemLib.c          |  4 +-
 .../Library/SmmPciExpressLib/PciExpressLib.c  |  4 +-  .../Library/SmmPciLibPciRootBridgeIo/PciLib.c |  6 +--
 .../SmmPeriodicSmiLib/SmmPeriodicSmiLib.c     | 42 +++++++++----------
 .../SmmServicesTableLib/SmmServicesTableLib.c |  2 +-
 8 files changed, 36 insertions(+), 36 deletions(-)

diff --git a/MdePkg/Include/Library/SmmLib.h b/MdePkg/Include/Library/SmmLib.h index 8d83df7fd737..bcb7045c1b65 100644
--- a/MdePkg/Include/Library/SmmLib.h
+++ b/MdePkg/Include/Library/SmmLib.h
@@ -45,7 +45,7 @@ TriggerRuntimeSoftwareSmi (
   it was triggered at boot time, it returns TRUE. Otherwise, it returns FALSE.
 
   @retval TRUE   A software SMI triggered at boot time happened.
-  @retval FLASE  No software SMI happened, or the software SMI was triggered at run time.
+  @retval FALSE  No software SMI happened, or the software SMI was triggered at run time.
 
 **/
 BOOLEAN
@@ -62,7 +62,7 @@ IsBootServiceSoftwareSmi (
   it was triggered at run time, it returns TRUE. Otherwise, it returns FALSE.
 
   @retval TRUE   A software SMI triggered at run time happened.
-  @retval FLASE  No software SMI happened or the software SMI was triggered at boot time.
+  @retval FALSE  No software SMI happened or the software SMI was triggered at boot time.
 
 **/
 BOOLEAN
diff --git a/MdePkg/Include/Library/SmmMemLib.h b/MdePkg/Include/Library/SmmMemLib.h
index 72edc9adcde7..d92cbd9aabd2 100644
--- a/MdePkg/Include/Library/SmmMemLib.h
+++ b/MdePkg/Include/Library/SmmMemLib.h
@@ -67,7 +67,7 @@ SmmCopyMemToSmram (
   @param  SourceBuffer        The pointer to the source buffer of the memory copy.
   @param  Length              The number of bytes to copy from SourceBuffer to DestinationBuffer.
 
-  @retval EFI_SECURITY_VIOLATION The DesinationBuffer is invalid per processor architecture or overlap with SMRAM.
+  @retval EFI_SECURITY_VIOLATION The DestinationBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SUCCESS            Memory is copied.
 
 **/
@@ -92,7 +92,7 @@ SmmCopyMemFromSmram (
   @param  SourceBuffer        The pointer to the source buffer of the memory copy.
   @param  Length              The number of bytes to copy from SourceBuffer to DestinationBuffer.
 
-  @retval EFI_SECURITY_VIOLATION The DesinationBuffer is invalid per processor architecture or overlap with SMRAM.
+  @retval EFI_SECURITY_VIOLATION The DestinationBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SECURITY_VIOLATION The SourceBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SUCCESS            Memory is copied.
 
diff --git a/MdePkg/Include/Library/SmmPeriodicSmiLib.h b/MdePkg/Include/Library/SmmPeriodicSmiLib.h
index 6215aa2232ac..a3e086d02501 100644
--- a/MdePkg/Include/Library/SmmPeriodicSmiLib.h
+++ b/MdePkg/Include/Library/SmmPeriodicSmiLib.h
@@ -64,7 +64,7 @@ PeriodicSmiExit (
   This function yields control back to the SMM Foundation.  When the next
   periodic SMI for the currently executing handler is triggered, the periodic
   SMI handler will be resumed and this function will return.  Use of this
-  function requires a seperate stack for the periodic SMI handler.  A non zero
+  function requires a separate stack for the periodic SMI handler.  A 
+ non zero
   stack size must be specified in PeriodicSmiEnable() for this function to be
   used.
 
@@ -113,7 +113,7 @@ VOID
   @param[in]     DispatchFunction  A pointer to a periodic SMI handler function.
   @param[in]     Context           Optional content to pass into DispatchFunction.
   @param[in]     TickPeriod        The requested tick period in 100ns units that
-                                   control should be givien to the periodic SMI
+                                   control should be given to the 
+ periodic SMI
                                    handler.  Must be one of the supported values
                                    returned by PeriodicSmiSupportedPickPeriod().
   @param[in]     Cpu               Specifies the CPU that is required to execute
@@ -137,7 +137,7 @@ VOID
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources to enable the
                                  periodic SMI handler.
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources to allocate the
-                                 stack speficied by StackSize.
+                                 stack specified by StackSize.
   @retval EFI_SUCCESS            The periodic SMI handler was enabled.
 
 **/
diff --git a/MdePkg/Library/SmmMemLib/SmmMemLib.c b/MdePkg/Library/SmmMemLib/SmmMemLib.c
index 7169bbdd10d8..63a4ff7a97f1 100644
--- a/MdePkg/Library/SmmMemLib/SmmMemLib.c
+++ b/MdePkg/Library/SmmMemLib/SmmMemLib.c
@@ -275,7 +275,7 @@ SmmCopyMemToSmram (
   @param  SourceBuffer        The pointer to the source buffer of the memory copy.
   @param  Length              The number of bytes to copy from SourceBuffer to DestinationBuffer.
 
-  @retval EFI_SECURITY_VIOLATION The DesinationBuffer is invalid per processor architecture or overlap with SMRAM.
+  @retval EFI_SECURITY_VIOLATION The DestinationBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SUCCESS            Memory is copied.
 
 **/
@@ -308,7 +308,7 @@ SmmCopyMemFromSmram (
   @param  SourceBuffer        The pointer to the source buffer of the memory copy.
   @param  Length              The number of bytes to copy from SourceBuffer to DestinationBuffer.
 
-  @retval EFI_SECURITY_VIOLATION The DesinationBuffer is invalid per processor architecture or overlap with SMRAM.
+  @retval EFI_SECURITY_VIOLATION The DestinationBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SECURITY_VIOLATION The SourceBuffer is invalid per processor architecture or overlap with SMRAM.
   @retval EFI_SUCCESS            Memory is copied.
 
diff --git a/MdePkg/Library/SmmPciExpressLib/PciExpressLib.c b/MdePkg/Library/SmmPciExpressLib/PciExpressLib.c
index 80c0154f5fad..35b9f775a80b 100644
--- a/MdePkg/Library/SmmPciExpressLib/PciExpressLib.c
+++ b/MdePkg/Library/SmmPciExpressLib/PciExpressLib.c
@@ -1226,7 +1226,7 @@ PciExpressBitFieldAndThenOr32 (
  Size into the buffer specified by Buffer. This function only allows the PCI
  configuration registers from a single PCI function to be read. Size is
  returned. When possible 32-bit PCI configuration read cycles are used to read
- from StartAdress to StartAddress + Size. Due to alignment restrictions, 8-bit
+ from StartAddress to StartAddress + Size. Due to alignment 
+ restrictions, 8-bit
  and 16-bit PCI configuration read cycles may be used at the beginning and the
  end of the range.
 
@@ -1329,7 +1329,7 @@ PciExpressReadBuffer (
  Size from the buffer specified by Buffer. This function only allows the PCI
  configuration registers from a single PCI function to be written. Size is
  returned. When possible 32-bit PCI configuration write cycles are used to
- write from StartAdress to StartAddress + Size. Due to alignment restrictions,
+ write from StartAddress to StartAddress + Size. Due to alignment 
+ restrictions,
  8-bit and 16-bit PCI configuration write cycles may be used at the beginning
  and the end of the range.
 
diff --git a/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c b/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
index c9660f48d700..49ea99ce1f05 100644
--- a/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
+++ b/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
@@ -35,7 +35,7 @@
   ((((A) << 4) & 0xff000000) | (((A) >> 4) & 0x00000700) | (((A) << 1) & 0x001f0000) | (LShiftU64((A) & 0xfff, 32)))
 
 //
-// Global varible to cache pointer to PCI Root Bridge I/O protocol.
+// Global variable to cache pointer to PCI Root Bridge I/O protocol.
 //
 EFI_SMM_PCI_ROOT_BRIDGE_IO_PROTOCOL      *mSmmPciRootBridgeIo = NULL;
 
@@ -1238,7 +1238,7 @@ PciBitFieldAndThenOr32 (
   Size into the buffer specified by Buffer. This function only allows the PCI
   configuration registers from a single PCI function to be read. Size is
   returned. When possible 32-bit PCI configuration read cycles are used to read
-  from StartAdress to StartAddress + Size. Due to alignment restrictions, 8-bit
+  from StartAddress to StartAddress + Size. Due to alignment 
+ restrictions, 8-bit
   and 16-bit PCI configuration read cycles may be used at the beginning and the
   end of the range.
 
@@ -1336,7 +1336,7 @@ PciReadBuffer (
   Size from the buffer specified by Buffer. This function only allows the PCI
   configuration registers from a single PCI function to be written. Size is
   returned. When possible 32-bit PCI configuration write cycles are used to
-  write from StartAdress to StartAddress + Size. Due to alignment restrictions,
+  write from StartAddress to StartAddress + Size. Due to alignment 
+ restrictions,
   8-bit and 16-bit PCI configuration write cycles may be used at the beginning
   and the end of the range.
 
diff --git a/MdePkg/Library/SmmServicesTableLib/SmmServicesTableLib.c b/MdePkg/Library/SmmServicesTableLib/SmmServicesTableLib.c
index d95e9d473790..0f611cd25df7 100644
--- a/MdePkg/Library/SmmServicesTableLib/SmmServicesTableLib.c
+++ b/MdePkg/Library/SmmServicesTableLib/SmmServicesTableLib.c
@@ -36,7 +36,7 @@ SmmServicesTableLibConstructor (
   //
   // Retrieve SMM Base2 Protocol,  Do not use gBS from UefiBootServicesTableLib on purpose
   // to prevent inclusion of gBS, gST, and gImageHandle from SMM Drivers unless the
-  // SMM driver explicity declares that dependency.
+  // SMM driver explicitly declares that dependency.
   //
   Status = SystemTable->BootServices->LocateProtocol (
                                         &gEfiSmmBase2ProtocolGuid,
diff --git a/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c b/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
index ba01910b696b..8b1e780b76db 100644
--- a/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
+++ b/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
@@ -107,8 +107,8 @@ typedef struct {
   UINT64                                   DispatchTotalTime;
   ///
   /// The performance counter value that was captured the last time that the
-  /// periodic SMI handler called PeriodcSmiExecutionTime().  This allows the
-  /// time value returned by PeriodcSmiExecutionTime() to be accurate even when
+  /// periodic SMI handler called PeriodicSmiExecutionTime().  This 
+ allows the  /// time value returned by PeriodicSmiExecutionTime() to 
+ be accurate even when
   /// the performance counter rolls over.
   ///
   UINT64                                   DispatchCheckPointTime;
@@ -127,7 +127,7 @@ typedef struct {
   ///
   /// Buffer used to save the context when a periodic SMI handler requests to
   /// yield using PeriodicSmiYield().  This context is used to resume the
-  /// execution of a periodic SMI handler the next time control is transferd
+  /// execution of a periodic SMI handler the next time control is 
+ transferred
   /// to the periodic SMI handler that yielded.
   ///
   BASE_LIBRARY_JUMP_BUFFER                 YieldJumpBuffer;
@@ -152,7 +152,7 @@ typedef struct {
     )
 
 ///
-/// Pointer to the SMM Periodic Timer Disatch Protocol that was located in the constuctor.
+/// Pointer to the SMM Periodic Timer Dispatch Protocol that was located in the constructor.
 ///
 EFI_SMM_PERIODIC_TIMER_DISPATCH2_PROTOCOL  *gSmmPeriodicTimerDispatch2           = NULL;
 
@@ -522,7 +522,7 @@ PeriodicSmiExit (
   This function yields control back to the SMM Foundation.  When the next
   periodic SMI for the currently executing handler is triggered, the periodic
   SMI handler will be resumed and this function will return.  Use of this
-  function requires a seperate stack for the periodic SMI handler.  A non zero
+  function requires a separate stack for the periodic SMI handler.  A 
+ non zero
   stack size must be specified in PeriodicSmiEnable() for this function to be
   used.
 
@@ -572,7 +572,7 @@ PeriodicSmiYield (
   SetJumpFlag = SetJump (&PeriodicSmiLibraryHandler->YieldJumpBuffer);
   if (SetJumpFlag == 0) {
     //
-    // The intial call to SetJump() always returns 0.
+    // The initial call to SetJump() always returns 0.
     // If this is the initial call, then exit the current periodic SMI handler
     //
     PeriodicSmiExit ();
@@ -588,7 +588,7 @@ PeriodicSmiYield (
   PeriodicSmiLibraryHandler->YieldFlag = FALSE;
 
   //
-  // Return the amount elapsed time that occured while yielded
+  // Return the amount elapsed time that occurred while yielded
   //
   return PeriodicSmiLibraryHandler->ElapsedTime;
 }
@@ -620,7 +620,7 @@ PeriodicSmiDispatchFunctionSwitchStack (
   //
   // Dispatch the registered handler passing in the context that was registered
   // and the amount of time that has elapsed since the previous time this
-  // periodic SMI handler was dispacthed.
+  // periodic SMI handler was dispatched.
   //
   PeriodicSmiLibraryHandler->DispatchFunction (
     PeriodicSmiLibraryHandler->Context,
@@ -628,16 +628,16 @@ PeriodicSmiDispatchFunctionSwitchStack (
     );
 
   //
-  // If this DispatchFunction() returns, then unconditially call PeriodicSmiExit()
+  // If this DispatchFunction() returns, then unconditionally call 
+ PeriodicSmiExit()
   // to perform a LongJump() back to PeriodicSmiDispatchFunctionOnCpu(). The
   // LongJump() will resume exection on the original stack.
   //
   PeriodicSmiExit ();
 }
 
 /**
   Internal worker function that transfers control to an enabled periodic SMI
-  handler on the specified logial CPU.  This function determines if the periodic
+  handler on the specified logical CPU.  This function determines if 
+ the periodic
   SMI handler yielded and needs to be resumed.  It also and switches to an
   allocated stack if one was allocated in PeriodicSmiEnable().
 
@@ -652,9 +652,9 @@ PeriodicSmiDispatchFunctionOnCpu (
   )
 {
   //
-  // Save context in DispatchJumpBuffer.  The intial call to SetJump() always
+  // Save context in DispatchJumpBuffer.  The initial call to SetJump() 
+ always
   // returns 0.  If this is the initial call, then either resume from a prior
-  // call to PeriodicSmiYield() or call the DispatchFunction registerd in
+  // call to PeriodicSmiYield() or call the DispatchFunction registered 
+ in
   // PeriodicSmiEnable() using an allocated stack if one was specified.
   //
   if (SetJump (&PeriodicSmiLibraryHandler->DispatchJumpBuffer) != 0) { @@ -679,7 +679,7 @@ PeriodicSmiDispatchFunctionOnCpu (
     //
     // If Stack is NULL then call DispatchFunction using current stack passing
     // in the context that was registered and the amount of time that has
-    // elapsed since the previous time this periodic SMI handler was dispacthed.
+    // elapsed since the previous time this periodic SMI handler was dispatched.
     //
     PeriodicSmiLibraryHandler->DispatchFunction (
       PeriodicSmiLibraryHandler->Context,
@@ -687,7 +687,7 @@ PeriodicSmiDispatchFunctionOnCpu (
       );
 
     //
-    // If this DispatchFunction() returns, then unconditially call PeriodicSmiExit()
+    // If this DispatchFunction() returns, then unconditionally call 
+ PeriodicSmiExit()
     // to perform a LongJump() back to this function.
     //
     PeriodicSmiExit ();
@@ -712,7 +712,7 @@ PeriodicSmiDispatchFunctionOnCpu (
 
 /**
   Internal worker function that transfers control to an enabled periodic SMI
-  handler on the specified logial CPU.  This worker function is only called
+  handler on the specified logical CPU.  This worker function is only 
+ called
   using the SMM Services Table function SmmStartupThisAp() to execute the
   periodic SMI handler on a logical CPU that is different than the one that is
   running the SMM Foundation.  When the periodic SMI handler returns, a lock is @@ -736,7 +736,7 @@ PeriodicSmiDispatchFunctionWithLock (
   PeriodicSmiLibraryHandler = (PERIODIC_SMI_LIBRARY_HANDLER_CONTEXT  *)Buffer;
 
   //
-  // Execute dispatch function on the currently excuting logical CPU
+  // Execute dispatch function on the currently executing logical CPU
   //
   PeriodicSmiDispatchFunctionOnCpu (PeriodicSmiLibraryHandler);
 
@@ -805,7 +805,7 @@ PeriodicSmiDispatchFunction (
       (PeriodicSmiLibraryHandler->Cpu == gSmst->CurrentlyExecutingCpu)    ) {
     //
     // Dispatch on the currently execution CPU if the CPU specified in PeriodicSmiEnable()
-    // was PERIODIC_SMI_LIBARRY_ANY_CPU or the currently executing CPU matches the CPU
+    // was PERIODIC_SMI_LIBRARY_ANY_CPU or the currently executing CPU 
+ matches the CPU
     // that was specified in PeriodicSmiEnable().
     //
     PeriodicSmiDispatchFunctionOnCpu (PeriodicSmiLibraryHandler); @@ -867,7 +867,7 @@ PeriodicSmiDispatchFunction (
   @param[in]     DispatchFunction  A pointer to a periodic SMI handler function.
   @param[in]     Context           Optional content to pass into DispatchFunction.
   @param[in]     TickPeriod        The requested tick period in 100ns units that
-                                   control should be givien to the periodic SMI
+                                   control should be given to the 
+ periodic SMI
                                    handler.  Must be one of the supported values
                                    returned by PeriodicSmiSupportedPickPeriod().
   @param[in]     Cpu               Specifies the CPU that is required to execute
@@ -891,7 +891,7 @@ PeriodicSmiDispatchFunction (
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources to enable the
                                  periodic SMI handler.
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources to allocate the
-                                 stack speficied by StackSize.
+                                 stack specified by StackSize.
   @retval EFI_SUCCESS            The periodic SMI handler was enabled.
 
 **/
@@ -1077,7 +1077,7 @@ SmmPeriodicSmiLibConstructor (
 
   //
   // Count the number of periodic SMI tick intervals that the SMM Periodic Timer
-  // Dipatch 2 Protocol supports.
+  // Dispatch 2 Protocol supports.
   //
   SmiTickInterval = NULL;
   Count = 0;
@@ -628,16 +628,16 @@ PeriodicSmiDispatchFunctionSwitchStack (
   // to perform a LongJump() back to PeriodicSmiDispatchFunctionOnCpu(). The
-  // LongJump() will resume exection on the original stack.
+  // LongJump() will resume execution on the original stack.
   //
   PeriodicSmiExit ();
--
2.21.0


  reply	other threads:[~2020-01-06  3:35 UTC|newest]

Thread overview: 122+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-01-03  9:06 [PATCH v2 00/78] Fix a bunch of typos (part 1) Philippe Mathieu-Daudé
2020-01-03  9:06 ` [PATCH v2 01/78] CryptoPkg/OpensslLib: Fix few typos Philippe Mathieu-Daudé
2020-01-06  2:39   ` Wang, Jian J
2020-01-03  9:06 ` [PATCH v2 02/78] EmbeddedPkg/VirtualKeyboard: Fix a typo in EFI_INVALID_PARAMETER Philippe Mathieu-Daudé
2020-01-08 12:41   ` Ard Biesheuvel
2020-01-03  9:06 ` [PATCH v2 03/78] EmbeddedPkg/VirtualKeyboard: Fix few typos Philippe Mathieu-Daudé
2020-01-08 12:42   ` Ard Biesheuvel
2020-01-08 14:26     ` Philippe Mathieu-Daudé
2020-01-03  9:06 ` [PATCH v2 04/78] EmulatorPkg/Sec: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:06 ` [PATCH v2 05/78] EmulatorPkg/Unix: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 06/78] EmulatorPkg/Win: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 07/78] FatPkg/EnhancedFatDxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 08/78] FatPkg/FatPei: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 09/78] MdeModulePkg/Application: Improve French translation Philippe Mathieu-Daudé
2020-02-07  0:49   ` Philippe Mathieu-Daudé
2020-02-07  0:53   ` [edk2-devel] " Wu, Hao A
2020-02-07  0:55     ` Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 10/78] MdeModulePkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-02-07  0:26   ` [edk2-devel] " Wu, Hao A
2020-01-03  9:07 ` [PATCH v2 11/78] MdeModulePkg/Bus/Ata: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 12/78] MdeModulePkg/Bus/I2c: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 13/78] MdeModulePkg/Bus/Isa: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 14/78] MdeModulePkg/Bus/Scsi: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 15/78] MdeModulePkg/Bus/Sd: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 16/78] MdeModulePkg/Core/Pei: " Philippe Mathieu-Daudé
2020-02-07  0:26   ` Wu, Hao A
2020-01-03  9:07 ` [PATCH v2 17/78] MdeModulePkg/Core/PiSmmCore: " Philippe Mathieu-Daudé
2020-02-07  0:26   ` Wu, Hao A
2020-01-03  9:07 ` [PATCH v2 18/78] MdeModulePkg/UsbBusDxe: Fix a typo Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 19/78] MdeModulePkg/UsbMass: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 20/78] MdeModulePkg/UsbMouse: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 21/78] MdeModulePkg/UsbBus: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 22/78] MdeModulePkg/Usb: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 23/78] MdePkg/IndustryStandard: " Philippe Mathieu-Daudé
2020-01-06  3:32   ` Liming Gao
2020-01-03  9:07 ` [PATCH v2 24/78] MdePkg/Library/Dxe: " Philippe Mathieu-Daudé
2020-01-06  3:35   ` Liming Gao
2020-01-03  9:07 ` [PATCH v2 25/78] MdePkg/Library/Pci: " Philippe Mathieu-Daudé
2020-01-06  3:35   ` [edk2-devel] " Liming Gao
2020-01-03  9:07 ` [PATCH v2 26/78] MdePkg/Library/Smm: " Philippe Mathieu-Daudé
2020-01-06  3:35   ` Liming Gao [this message]
2020-01-03  9:07 ` [PATCH v2 27/78] MdePkg/Ppi: " Philippe Mathieu-Daudé
2020-01-06  3:36   ` [edk2-devel] " Liming Gao
2020-01-03  9:07 ` [PATCH v2 28/78] MdePkg/Register: " Philippe Mathieu-Daudé
2020-01-06  3:38   ` Liming Gao
2020-01-03  9:07 ` [PATCH v2 29/78] NetworkPkg: Fix a typo Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 30/78] NetworkPkg/ArpDxe: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 31/78] NetworkPkg/Dhcp4Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 32/78] NetworkPkg/Dhcp6Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 33/78] NetworkPkg/DnsDxe: Fix a typo Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 34/78] NetworkPkg/DnsDxe: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 35/78] NetworkPkg/DpcDxe: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 36/78] NetworkPkg/HttpBootDxe: Fix a typo in variable name Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 37/78] NetworkPkg/HttpBootDxe: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 38/78] NetworkPkg/HttpDxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 39/78] NetworkPkg/Ip4Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 40/78] NetworkPkg/Ip6Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 41/78] NetworkPkg/IScsiDxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 42/78] NetworkPkg/Library: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 43/78] NetworkPkg/MnpDxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 44/78] NetworkPkg/Mtftp4Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 45/78] NetworkPkg/Mtftp6Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 46/78] NetworkPkg/SnpDxe: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 47/78] NetworkPkg/TcpDxe/Sock: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 48/78] NetworkPkg/TcpDxe/Tcp: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 49/78] NetworkPkg/Tls: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 50/78] NetworkPkg/Udp4Dxe: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 51/78] NetworkPkg/Udp6Dxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 52/78] NetworkPkg/UefiPxeBcDxe: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 53/78] NetworkPkg/VlanConfigDxe: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 54/78] OvmfPkg/Acpi: " Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 55/78] OvmfPkg/Csm: Fix various typos Philippe Mathieu-Daudé
2020-01-03 13:40   ` [edk2-devel] " Laszlo Ersek
2020-01-03  9:07 ` [PATCH v2 56/78] OvmfPkg/Csm/LegacyBios: Fix a typo Philippe Mathieu-Daudé
2020-01-03 13:40   ` [edk2-devel] " Laszlo Ersek
2020-01-03  9:07 ` [PATCH v2 57/78] OvmfPkg/Qemu: Fix various typos Philippe Mathieu-Daudé
2020-01-03 13:37   ` Laszlo Ersek
2020-01-03  9:07 ` [PATCH v2 58/78] OvmfPkg/Virtio: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 59/78] OvmfPkg/Xen: Fix a typo Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 60/78] OvmfPkg/Xen: Fix various typos Philippe Mathieu-Daudé
2020-01-03 13:42   ` [edk2-devel] " Laszlo Ersek
2020-01-06 10:36     ` Anthony PERARD
2020-01-06 16:06       ` Laszlo Ersek
2020-01-03  9:07 ` [PATCH v2 61/78] PcAtChipsetPkg: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:07 ` [PATCH v2 62/78] SecurityPkg: " Philippe Mathieu-Daudé
2020-01-03  9:56   ` [edk2-devel] " Yao, Jiewen
2020-01-03  9:07 ` [PATCH v2 63/78] SecurityPkg/Hash2DxeCrypto: " Philippe Mathieu-Daudé
2020-01-03  9:55   ` [edk2-devel] " Yao, Jiewen
2020-01-03  9:07 ` [PATCH v2 64/78] SecurityPkg/Library/Tpm: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:54   ` Yao, Jiewen
2020-01-03  9:07 ` [PATCH v2 65/78] SecurityPkg/Tcg: " Philippe Mathieu-Daudé
2020-01-03  9:56   ` [edk2-devel] " Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 66/78] SecurityPkg/VariableAuthenticated: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:56   ` Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 67/78] ShellPkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-01-03  9:08 ` [PATCH v2 68/78] ShellPkg/DynamicCommand: " Philippe Mathieu-Daudé
2020-01-03  9:08 ` [PATCH v2 69/78] SignedCapsulePkg: " Philippe Mathieu-Daudé
2020-01-03  9:56   ` Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 70/78] SignedCapsulePkg/Universal: " Philippe Mathieu-Daudé
2020-01-03 12:13   ` Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 71/78] SourceLevelDebugPkg/DebugAgent: " Philippe Mathieu-Daudé
2020-01-03  9:08 ` [PATCH v2 72/78] SourceLevelDebugPkg/DebugCommunicationLib: " Philippe Mathieu-Daudé
2020-01-03  9:08 ` [PATCH v2 73/78] SourceLevelDebugPkg: Fix few typos Philippe Mathieu-Daudé
2020-01-03  9:08 ` [PATCH v2 74/78] StandaloneMmPkg: Fix a typo Philippe Mathieu-Daudé
2020-01-03 12:13   ` [edk2-devel] " Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 75/78] StandaloneMmPkg: Fix few typos Philippe Mathieu-Daudé
2020-01-03 12:14   ` Yao, Jiewen
2020-01-03  9:08 ` [PATCH v2 76/78] UefiCpuPkg/CpuDxe: " Philippe Mathieu-Daudé
2020-01-07  8:28   ` [edk2-devel] " Dong, Eric
2020-01-03  9:08 ` [PATCH v2 77/78] UefiCpuPkg/PiSmm: Fix various typos Philippe Mathieu-Daudé
2020-01-07  8:27   ` [edk2-devel] " Dong, Eric
2020-01-03  9:08 ` [PATCH v2 78/78] UefiCpuPkg/Smm: " Philippe Mathieu-Daudé
2020-01-07  8:28   ` Dong, Eric
2020-01-03 10:59 ` [PATCH v2 00/78] Fix a bunch of typos (part 1) Cœur
2020-01-07 12:44 ` [edk2-devel] " Maciej Rabeda
2020-01-17 17:13 ` Philippe Mathieu-Daudé
2020-01-19  5:14   ` [edk2-devel] " Liming Gao
2020-01-20  8:35     ` Philippe Mathieu-Daudé
2020-01-17 17:15 ` Philippe Mathieu-Daudé
2020-02-06 23:46   ` Philippe Mathieu-Daudé
2020-02-10 15:22 ` [edk2-devel] " Maciej Rabeda
2020-02-10 23:51   ` 答复: " Yao, Jiewen

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=4A89E2EF3DFEDB4C8BFDE51014F606A14E58A495@SHSMSX104.ccr.corp.intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox